Page 102 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 102

Home

    Getting Your Share?’ the essence of De Leon's speech
    was that, according to government statistics, labor's

    The tragedy of De Leon's conclusion was that it was
    just the opposite of the truth. As it turned out, De Leon
    made a colossal mistake because he only considered the
    cost of labor in the final stage of manufacturing,
    overlooking the cost of labor along the line from raw
    material to finished product. When all of the cost of labor

    is added up, labor gets the 80 percent, owners get the 20
    percent. Out of the 20 percent must then come the

    expense of overhead, taxes, etc. until finally, the net
    profit is often as low as 2 or 3 percent, or, no profit at
    all.

    Actually, according to U. S. Department of
    Commerce figures, the worker's share is 87.5 percent and
    the owners’ share is 12.5 percent. Compare this with

    of

    to

    barely

    enough

    barely enough of produced wealth to exist, the
    government getting the rest.

    Having failed in their first attempt to get the United
    States to join the League of Nations, the War-makers set
    out to create a conflagration so terrible that the aftermath

    wealth

    exist,

    the

    to

    The same powerful financial interests that worked to
    get the United States into World War I worked with the

    97

    Building Modern Babylon

    share of manufactured wealth was on the average 20

    percent while the owner's share was 80 percent.

    according

    socialist nations around the world where workers receive

    would sweep the entire world into a one world

    government.

    now well-established Council on Foreign Relations to set